@@ -1,12 +1,13 @@
 /*!
   \file
-  \brief f[^̓ǂݏo(PC)
+  \brief f[^̓ǂݏ([J)
 
   \author Satofumi KAMIMURA
 
   $Id$
 
   \todo strftime g
+  \todo L^f[^̃o[WŃ}CNȏオقȂꍇɁAgpȂ
 */
 
 #include "AccessRecordPC.h"
@@ -97,6 +98,15 @@ bool AccessRecordPC::load(std::vector<TypingRecorder::GameSettings>& data,
     size_t length = file_name.size();
     std::string player_name = file_name.substr(9, length - 13);
 
+    if (file_name.empty()) {
+      // t@C@
+      continue;
+    }
+    if (file_name[0] != ((pimpl->mode_ == ShimonokuTyping) ? 's' : 'k')) {
+      // [hႤ
+      continue;
+    }
+
     if (player_name.compare(user_name)) {
       // [UႤ
       continue;
@@ -110,6 +120,7 @@ bool AccessRecordPC::load(std::vector<TypingRecorder::GameSettings>& data,
     file_tm.tm_mday = static_cast<int>(day);
     file_tm.tm_mon = static_cast<int>(month - 1);
     file_tm.tm_year = static_cast<int>(year - 1900);
+    file_tm.tm_isdst = 0;
     time_t file_ctime_first = mktime(&file_tm);
     time_t file_ctime_last = file_ctime_first + (60 * 60 * 24);
 
@@ -147,28 +158,34 @@ bool AccessRecordPC::load(std::vector<TypingRecorder::GameSettings>& data,
     escaped_list_separator<char> esc;
     tokenizer<escaped_list_separator<char> > tokens(*lit, esc);
 
-    // !!! TCYāAAǂ݂₷
-    int index = 0;
-    for (tokenizer<escaped_list_separator<char> >::iterator it =
-           tokens.begin(); it != tokens.end(); ++it, ++index) {
-      if (index == 0) {
-        setting.time = lexical_cast<time_t>(*it);
-      } else if (index == 1) {
-        setting.mode = pimpl->mode_;
-      } else if (index == 2) {
-        setting.user_name = user_name;
-      } else if (index == 3) {
-        setting.rand_seed = lexical_cast<long>(*it);
-      } else if (index == 4) {
-        setting.score.miss_types = lexical_cast<int>(*it);
-      } else if (index == 5) {
-        setting.score.delay_msec = lexical_cast<int>(*it);
-      } else if (index == 6) {
-        setting.score.elapse_msec = lexical_cast<int>(*it);
-      } else if (index == 7) {
-        // waka_num = lexical_cast<int>(*it);
-      }
+    setting.waka_num = 1;
+
+    // !!! TCY̊mFāA++ Ȃf[^oׂ
+    // !!! ܂ATCY̊mF͌
+
+    tokenizer<escaped_list_separator<char> >::iterator it = tokens.begin();
+
+    setting.time = lexical_cast<time_t>(*it); ++it;
+    setting.major_version = *it; ++it;
+    setting.minor_version = *it; ++it;
+    setting.micro_version = *it; ++it;
+
+    // Major, Minor o[WقȂf[^͈Ȃ
+    if (0) {
+      continue;
     }
+
+    setting.mode = pimpl->mode_; ++it;
+    setting.user_name = user_name; ++it;
+    setting.rand_seed = lexical_cast<long>(*it); ++it;
+    setting.score.miss_types = lexical_cast<int>(*it); ++it;
+    setting.score.delay_msec = lexical_cast<int>(*it); ++it;
+    setting.score.elapse_msec = lexical_cast<int>(*it); ++it;
+    setting.score.types = lexical_cast<int>(*it); ++it;
+    setting.waka_num = lexical_cast<int>(*it); ++it;
+    setting.kaminoku_speed = lexical_cast<int>(*it); ++it;
+    setting.shimonoku_speed = lexical_cast<int>(*it); ++it;
+
     data.push_back(setting);
   }
 
