@@ -20,6 +20,7 @@
 #include <boost/lexical_cast.hpp>
 
 using namespace beego;
+using namespace boost;
 
 
 struct AccessSettings::pImpl {
@@ -70,7 +71,8 @@ struct AccessSettings::pImpl {
 
     const char* tag[] = {
       "u_%02d", "u_%02d_http", "u_%02d_password", "u_%02d_converter",
-      "u_%02d_num",
+      "u_%02d_num", "u_%02d_music", "u_%02d_effect", "u_%02d_voice",
+      "u_%02d_practice", "u_%02d_send",
     };
 
     enum { BufferMax = 256 };
@@ -108,13 +110,17 @@ void AccessSettings::reload(void) {
   effect_type_ = property["effect_type"];
   effect_miss_ = property["effect_miss"];
 
-  // [U̐ݒ
+  // [Ȕ
   user_names_.resize(UserMax);
   user_password_.resize(UserMax);
+  server_address_.resize(UserMax);
   practice_num_.resize(UserMax);
   convert_mode_.resize(UserMax);
+  practice_mode_.resize(UserMax);
+  data_send_.resize(UserMax);
   music_volume_.resize(UserMax);
   effect_volume_.resize(UserMax);
+  voice_resource_.resize(UserMax);
   for (int i = 0; i < UserMax; ++i) {
 
     // !!! ɁÂ̏͊֐܂...
@@ -129,6 +135,11 @@ void AccessSettings::reload(void) {
     sprintf(password_tag, "u_%02d_password", i);
     user_password_[i] = property[password_tag];
 
+    // o^AhX
+    char http_tag[] = "u_xx_http";
+    sprintf(http_tag, "u_%02d_http", i);
+    server_address_[i] = property[http_tag];
+
     // K
     char num_tag[] = "u_xx_num";
     sprintf(num_tag, "u_%02d_num", i);
@@ -143,6 +154,16 @@ void AccessSettings::reload(void) {
     sprintf(converter_tag, "u_%02d_converter", i);
     convert_mode_[i] = atoi(property[converter_tag].c_str());
 
+    // K[h
+    char practice_tag[] = "u_xx_practice";
+    sprintf(practice_tag, "u_%02d_practice", i);
+    practice_mode_[i] = atoi(property[practice_tag].c_str());
+
+    // f[^M
+    char send_tag[] = "u_xx_send";
+    sprintf(send_tag, "u_%02d_send", i);
+    data_send_[i] = atoi(property[send_tag].c_str());
+
     // Ȃ̉
     char music_tag[] = "u_xx_music";
     sprintf(music_tag, "u_%02d_music", i);
@@ -154,6 +175,11 @@ void AccessSettings::reload(void) {
     sprintf(effect_tag, "u_%02d_effect", i);
     volume = atoi(property[effect_tag].c_str());
     effect_volume_[i] = volume;
+
+    // rݏグ\[X
+    char voice_tag[] = "u_xx_voice";
+    sprintf(voice_tag, "u_%02d_voice", i);
+    voice_resource_[i] = property[voice_tag];
   }
   user_index_ = atoi(property["u_index"].c_str());
 }
@@ -171,7 +197,7 @@ void AccessSettings::save(void) {
   AccessProperty& property = *pimpl->property_;
 
   // [UCfbNX̋L^
-  property["u_index"] = boost::lexical_cast<std::string>(user_index_);
+  property["u_index"] = lexical_cast<std::string>(user_index_);
 
   // [UApX[h̋L^
   for (int i = 0; i < UserMax; ++i) {
@@ -189,31 +215,46 @@ void AccessSettings::save(void) {
     sprintf(password_tag, "u_%02d_password", i);
     property[password_tag] = user_password_[i];
 
+    // o^AhX
+    char http_tag[] = "u_xx_http";
+    sprintf(http_tag, "u_%02d_http", i);
+    property[http_tag] = server_address_[i];
+
     // K
     char num_tag[] = "u_xx_num";
     sprintf(num_tag, "u_%02d_num", i);
-    property[num_tag] = boost::lexical_cast<std::string>(practice_num_[i]);
+    property[num_tag] = lexical_cast<std::string>(practice_num_[i]);
 
     // ̓[h
     char converter_tag[] = "u_xx_converter";
     sprintf(converter_tag, "u_%02d_converter", i);
-    property[converter_tag] =
-      boost::lexical_cast<std::string>(convert_mode_[i]);
+    property[converter_tag] = lexical_cast<std::string>(convert_mode_[i]);
+
+    // K[h
+    char practice_tag[] = "u_xx_practice";
+    sprintf(practice_tag, "u_%02d_practice", i);
+    property[practice_tag] = lexical_cast<std::string>(practice_mode_[i]);
+
+    // f[^M
+    char send_tag[] = "u_xx_send";
+    sprintf(send_tag, "u_%02d_send", i);
+    property[send_tag] = lexical_cast<std::string>(data_send_[i]);
 
     // Ȃ̉
     char music_tag[] = "u_xx_music";
     sprintf(music_tag, "u_%02d_music", i);
-    property[music_tag] =
-      boost::lexical_cast<std::string>(music_volume_[i]);
+    property[music_tag] = lexical_cast<std::string>(music_volume_[i]);
 
     // ʉ̉
     char effect_tag[] = "u_xx_effect";
     sprintf(effect_tag, "u_%02d_effect", i);
-    property[effect_tag] =
-      boost::lexical_cast<std::string>(effect_volume_[i]);
-  }
+    property[effect_tag] = lexical_cast<std::string>(effect_volume_[i]);
 
-  // !!!
+    // rݏグ\[X
+    char voice_tag[] = "u_xx_voice";
+    sprintf(voice_tag, "u_%02d_voice", i);
+    property[voice_tag] = voice_resource_[i];
+  }
 
   property.save();
 }
