@@ -19,6 +19,7 @@ struct CdromPlayer::pImpl : private SdlCdromInit {
   std::string error_message_;
   SDL_CD* cdrom_;
   size_t drives_;
+  std::vector<track_t> track_list_;
 
   pImpl(void) : error_message_("no error."), cdrom_(NULL), drives_(0) {
     openDrive();
@@ -67,15 +68,7 @@ struct CdromPlayer::pImpl : private SdlCdromInit {
       return false;
     }
 
-    return true;
-  }
-
-  bool getTrackList(std::vector<track_t>& list) {
-
-    if (! checkDrive()) {
-      return false;
-    }
-
+    track_list_.clear();
     for (int i = 0; i < cdrom_->numtracks; ++i) {
 
       track_t info;
@@ -87,21 +80,36 @@ struct CdromPlayer::pImpl : private SdlCdromInit {
       int frame;
       FRAMES_TO_MSF(track.length, &info.min, &info.sec, &frame);
 
-      list.push_back(info);
+      track_list_.push_back(info);
     }
+
     return true;
   }
 
-  void play(size_t id, size_t start_frame, size_t play_frame) {
+  bool getTrackList(std::vector<track_t>& list) {
+
     if (! checkDrive()) {
-      return;
+      return false;
+    }
+
+    list = track_list_;
+    return true;
+  }
+
+  bool play(size_t id, size_t start_frame, size_t play_frame) {
+    if (! checkDrive()) {
+      return false;
+    }
+
+    if ((id >= track_list_.size()) || (track_list_[id].type == DataTrack)) {
+      return false;
     }
 
     int ntrack = (play_frame == 0) ? 1 : 0;
-    //fprintf(stderr, "SDL_CDPlayTracks(cdrom_, %d, %d, %d, %d)\n", id, start_frame, ntrack, play_frame);
     SDL_CDPlayTracks(cdrom_, static_cast<int>(id),
                      static_cast<int>(start_frame),
                      ntrack, static_cast<int>(play_frame));
+    return true;
   }
 
   void stop(void) {
@@ -128,8 +136,20 @@ bool CdromPlayer::getTrackList(std::vector<track_t>& list) {
 }
 
 
-void CdromPlayer::play(size_t id, size_t start_frame, size_t play_frame) {
-  pimpl->play(id, start_frame, play_frame);
+size_t CdromPlayer::play(size_t id, size_t start_frame, size_t play_frame) {
+  if (! pimpl->play(id, start_frame, play_frame)) {
+    return 0;
+  }
+
+  size_t play_msec = 0;
+  if (play_frame != 0) {
+    play_msec = 1000 * play_frame / CD_FPS;
+
+  } else {
+    play_msec =
+      1000 * (pimpl->track_list_[id].frame_length - start_frame) / CD_FPS;
+  }
+  return play_msec;
 }
 
 
@@ -138,6 +158,6 @@ void CdromPlayer::stop(void) {
 }
 
 
-void CdromPlayer::efect(void) {
+void CdromPlayer::eject(void) {
   SDL_CDEject(pimpl->cdrom_);
 }
