@@ -42,15 +42,14 @@ namespace beego {
     const char* what(void);
 
     bool getTrackList(std::vector<track_t>& list);
-    void play(size_t id, size_t start_frame = 0, size_t play_frame = 0);
+    size_t play(size_t id, size_t start_frame = 0, size_t play_frame = 0);
     void stop(void);
 
     // !!! ĐhCu̎w
     // !!! CD ̗LmFH
-    void efect(void);
+    void eject(void);
     // !!! ĐԂ
     // !!! ꎞ~
-    // !!! o
   };
 };
 
