@@ -86,6 +86,31 @@ struct DrawPanelSurface::pImpl {
     }
   };
 
+  /*!
+    \brief `̕`
+  */
+  class DrawRectObject : public DrawObjectInterface {
+    Grid<int> position_;
+    size_t w_;
+    size_t h_;
+    Uint32 color_;
+
+  public:
+    DrawRectObject(const Grid<int>& position,
+                   size_t w, size_t h, Uint32 color)
+      : position_(position), w_(w), h_(h), color_(draw_getDrawColor(color)) {
+    }
+
+    void draw(const SDL_Rect* pos, const SDL_Rect* area) {
+
+      // pos ʒu𔽉f
+      int x = position_.x + pos->x;
+      int y = position_.y + pos->y;
+
+      draw_rect(x, y, w_, h_, color_);
+    }
+  };
+
   /*!
     \brief ̕`
   */
@@ -266,7 +291,6 @@ void DrawPanelSurface::drawLine(const Grid<int>& p1, const Grid<int>& p2,
 
   pImpl::DrawObjectInterface* p = new pImpl::DrawLineObject(p1, p2, color);
   pimpl->object_list.push_back(p);
-
   pimpl->is_changed = true;
 }
 
@@ -289,6 +313,16 @@ void DrawPanelSurface::drawLines(const std::vector<Grid<int> >& points,
 }
 
 
+void DrawPanelSurface::drawRect(const Grid<int>& position,
+                                size_t w, size_t h, Uint32 color) {
+
+  pImpl::DrawObjectInterface* p =
+    new pImpl::DrawRectObject(position, w, h, color);
+  pimpl->object_list.push_back(p);
+  pimpl->is_changed = true;
+}
+
+
 void DrawPanelSurface::drawText(const Grid<int>& position,
                                 const TextProperty& text, int mode) {
 
