@@ -20,6 +20,8 @@ enum {
   Selected = beego::Blue,
 
   Pink = 0xffc0cbff,
+  CornSilk = 0xfff8dcff,
+  DarkGreen = 0x00a000ff,
 };
 
 // tHgTCY
