@@ -73,6 +73,14 @@ struct GuiManager::pImpl {
     layer_manager_.redraw(update_rects_, surface_list_);
 
     if (scr_ && (! update_rects_.empty())) {
+#if 0
+      int n = update_rects_.size();
+      for (int i = 0; i < n; ++i) {
+        fprintf(stderr, "[%d, %d, %d, %d] ", update_rects_[i].x, update_rects_[i].y, update_rects_[i].w, update_rects_[i].h);
+      }
+      fprintf(stderr, "\n");
+#endif
+
       SDL_UpdateRects(scr_, static_cast<int>(update_rects_.size()),
                       &update_rects_[0]);
     }
