@@ -15,26 +15,35 @@
 
 namespace beego {
   class Layer;
+  class InputEvent;
 
   class GuiManager {
     GuiManager(const GuiManager& rhs);
     GuiManager& operator = (const GuiManager& rhs);
 
     struct pImpl;
-    const std::auto_ptr<pImpl> pimpl;
+    //const std::auto_ptr<pImpl> pimpl;
+    pImpl* pimpl;
 
   public:
+    typedef enum {
+      User,
+      Auto,
+    } RedrawMode;
     GuiManager(void);
+    GuiManager(RedrawMode mode);
     ~GuiManager(void);
-    SDL_mutex* getMutex(void);
-
-    void stop(void);
 
     void push_front(Layer* layer);
     void push_back(Layer* layer);
     void insert(const Layer* dst, Layer* layer);
     void remove(Layer* layer);
-    //size_t getRedrawTimes(void);
+
+    // !!! ͂̕]sAĕ`s
+    void update(void);
+
+    // !!! ͂̕]sAĕ`s
+    void redraw(void);
   };
 };
 
