@@ -76,12 +76,31 @@ bool HttpAccess::get(std::vector<char>& page, const char* address) {
   char ch;
   int n;
   bool now_header = true;
+  std::string line;
+  size_t left_byte = 0;         // cMoCg
+
   do {
-    n = pimpl->con_.recv(&ch, 1, 1000);
+    if (now_header) {
+      n = pimpl->con_.recv(&ch, 1, 1000);
+    } else {
+      // !!! obt@ɓǂݏoApage ɑ΂Ċi[ׂ
+      n = pimpl->con_.recv(&ch, (left_byte > 0 ? 1 : 0), 1000);
+      --left_byte;
+    }
     if (n > 0) {
 
       if (! now_header) {
         page.push_back(ch);
+      } else {
+        // si[AContent-Length: ̐lǂݏo
+        if (isprint(ch)) {
+          line.push_back(ch);
+        } else {
+          if (! line.compare(0, 16, "Content-Length: ")) {
+            left_byte = atoi(&line[16]);
+          }
+          line.clear();
+        }
       }
 
       if (pimpl->isLF(ch)) {
