@@ -5,6 +5,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo isPressed() B́AԂĂ
 */
 
 #include "InputEvent.h"
@@ -12,12 +14,11 @@
 using namespace beego;
 
 
-
 bool InputEvent::isPressed(const InputEvent& event, SDLKey key) {
 
   for (InputEvent::InputKeys::const_iterator it = event.key_pressed.begin();
        it != event.key_pressed.end(); ++it) {
-    if (it->sym == key) {
+    if (it->pressed_ && (it->sym_ == key)) {
       return true;
     }
   }
