@@ -119,11 +119,13 @@ struct InputHandler::pImpl : private SdlInit {
         for (EventMap::iterator it = events.begin();
              it != events.end(); ++it) {
           it->second.left_released = true;
+          it->second.left_pressing = false;
         }
       } else if (btn_event.type == SDL_MOUSEBUTTONDOWN) {
         for (EventMap::iterator it = events.begin();
              it != events.end(); ++it) {
           it->second.left_clicked = true;
+          it->second.left_pressing = true;
         }
       }
     }
