@@ -27,25 +27,26 @@ using namespace beego;
 
 
 struct NetworkMenu::pImpl {
-  CommonResources* common;
-  TtfResource* font;
-  TextProperty title_property;
-  Surface title_surface;
-  Component title_label;
-  boost::shared_ptr<MenuComponent> menu;
+  CommonResources* common_;
+  TtfResource* font_;
+  TextProperty title_property_;
+  Surface title_surface_;
+  Component title_label_;
+  boost::shared_ptr<MenuComponent> menu_;
 
   pImpl(void)
-    : common(CommonResources::getObject()),
-      title_property(common->font, NetworkMenu_title, TitleSize,
-                     Fore, Back, true),
-      title_surface(new TextSurface(title_property)),
-      title_label(new LabelComponent(title_surface)), menu(new MenuComponent) {
+    : common_(CommonResources::getObject()),
+      title_property_(common_->font_, NetworkMenu_title, TitleSize,
+                      Fore, Back, true),
+      title_surface_(new TextSurface(title_property_)),
+      title_label_(new LabelComponent(title_surface_)),
+      menu_(new MenuComponent) {
 
     // ^Cg̈ʒuݒ
     SDL_Rect position;
-    set_SdlRect(&position, centerPosition(title_label, 640/2),
-                middlePosition(title_label, 480/4));
-    title_label->setPosition(&position);
+    set_SdlRect(&position, centerPosition(title_label_, 640/2),
+                middlePosition(title_label_, 480/4));
+    title_label_->setPosition(&position);
 
     // j[̐Aʒuݒ
     const Uint16 *titles[] = {
@@ -56,35 +57,35 @@ struct NetworkMenu::pImpl {
     size_t max_width = 0;
     for (size_t i = 0; i < sizeof(titles)/sizeof(titles[0]); ++i) {
       boost::shared_ptr<ButtonComponent> new_button(new ButtonComponent);
-      TextProperty normal(common->font, titles[i], MenuSize,
+      TextProperty normal(common_->font_, titles[i], MenuSize,
                           Fore, Back, true);
-      TextProperty selected(common->font, titles[i], MenuSize,
+      TextProperty selected(common_->font_, titles[i], MenuSize,
                             Selected, Back, true);
       ButtonComponent::createButton(new_button, normal, selected, selected);
       if (new_button->getWidth() > max_width) {
         max_width = new_button->getWidth();
       }
-      menu->addItem(new_button);
+      menu_->addItem(new_button);
     }
-    menu->setItemsOffset(0, MenuSize + 16);
-    menu->setItemSelectWidth(max_width);
-    menu->setSelected(0);
-    menu->setIconComponent(common->menu_icon, IconOffset, 0, Middle | Left);
+    menu_->setItemsOffset(0, MenuSize + 16);
+    menu_->setItemSelectWidth(max_width);
+    menu_->setSelected(0);
+    menu_->setIconComponent(common_->menu_icon_, IconOffset, 0, Middle | Left);
 
-    set_SdlRect(&position, centerPosition(menu, 640/2),        480/4 + MenuOffset);
-    menu->setPosition(&position);
+    set_SdlRect(&position, centerPosition(menu_, 640/2), 480/4 + MenuOffset);
+    menu_->setPosition(&position);
   }
 
   void placeComponents(void) {
-    common->front_layer->push_front(title_label);
-    common->front_layer->push_front(menu);
-    common->front_layer->push_front(common->user_label);
+    common_->front_layer_->push_front(title_label_);
+    common_->front_layer_->push_front(menu_);
+    common_->front_layer_->push_front(common_->user_label_);
   }
 
   void removeComponents(void) {
-    common->front_layer->remove(title_label);
-    common->front_layer->remove(menu);
-    common->front_layer->remove(common->user_label);
+    common_->front_layer_->remove(title_label_);
+    common_->front_layer_->remove(menu_);
+    common_->front_layer_->remove(common_->user_label_);
   }
 };
 
@@ -101,16 +102,16 @@ NetworkMenu::~NetworkMenu(void) {
 
 void NetworkMenu::run(void) {
 
-  GuiManager* gui = pimpl->common->gui;
-  InputHandler& input = *pimpl->common->input;
+  GuiManager* gui = pimpl->common_->gui_;
+  InputHandler& input = *pimpl->common_->input_;
   bool quit = false;
   while (quit == false) {
 
-    int selected = pimpl->menu->getDecided();
+    int selected = pimpl->menu_->getDecided();
     if (selected >= 0) {
 
       // 艹炷
-      pimpl->common->playEffect(Decide);
+      pimpl->common_->playEffect(Decide);
 
       pimpl->removeComponents();
       if (selected == 0) {
@@ -132,14 +133,14 @@ void NetworkMenu::run(void) {
 
       // j[đI\ɂ
       pimpl->placeComponents();
-      pimpl->menu->releaseDecided();
+      pimpl->menu_->releaseDecided();
     }
 
     input.update_all();
     gui->update();
     quit |= input.isReleased(SDLK_ESCAPE);
     if (input.haveQuitEvent()) {
-      pimpl->common->front_layer->disable();
+      pimpl->common_->front_layer_->disable();
       quit |= true;
     }
     delay(1);
