@@ -6,12 +6,20 @@
 
   $Id$
 
+  \todo ԉ̍ڂAu߂vɂ
+  \todo ߂Aɓꂷ
+  \todo ^CsO̕\ŁA܂莚\邩ÃIvVڂǉ
+  \todo hbO𗣂A悤ɂ
+  \todo F̍ڂ͖ڗȂ̂AȂƂ
+  \todo VolumeSliderComponent {[ύXpۂ
+  \todo Pink F킩ɂ̂AȂƂ
+  \todo R{{bNXARsȏ゠ƂɁAƂɕ`悪ĉȂƂ
   \todo ڂ̐̓|bvAbvōs
-  \todo "guest" [ÛƂ́AT[oւ̃f[^M disable ɂ
-  \todo `FbN{bNX̑ÎC
+  \todo "guest" [ÛƂ́AT[oւ̃f[^MłȂƂm点
   \todo `FbN{bNX̐Fݒ𒲐
   \todo VolumeSliderComponent iD悭
   \todo VolumeSliderComponent ŁAhbO͓͂𗣂Ȃ悤ɂ
+  \todo ʂύXƂɁAʉ悤ɂ
 */
 
 #include "OptionMenu.h"
@@ -59,6 +67,7 @@ struct OptionMenu::pImpl {
 
   CommonResources* common_;
   size_t user_index_;
+  std::vector<std::string> voice_resources_;
   boost::shared_ptr<OptionMenuComponent> option_;
   Surface arrow_surface_;
   Component arrow_label_;
@@ -95,31 +104,32 @@ struct OptionMenu::pImpl {
 
   pImpl(void)
     : common_(CommonResources::getObject()),
-      user_index_(common_->settings->user_index_),
+      user_index_(common_->settings_->user_index_),
+      voice_resources_(common_->getAllVoiceResources()),
       option_(new OptionMenuComponent),
       arrow_surface_(new SdlSurface(createSurface(arrow_bmp,
                                                   arrow_bmp_width,
                                                   arrow_bmp_height), true)),
       arrow_label_(new LabelComponent(arrow_surface_)),
-      base_property_(common_->font, "", OptionSize, Fore, Back, true),
-      title_property_(common_->font, OptionMenu_title,
+      base_property_(common_->font_, "", OptionSize, Fore, Back, true),
+      title_property_(common_->font_, OptionMenu_title,
                       MenuSize, Fore, Back, true),
       title_surface_(new TextSurface(title_property_)),
       title_label_(new LabelComponent(title_surface_)),
-      escape_property_(common_->font, OptionMenu_escape,
+      escape_property_(common_->font_, OptionMenu_escape,
                        OptionSize, Fore, Back, true),
-      escape_focus_property_(common_->font, OptionMenu_escape,
+      escape_focus_property_(common_->font_, OptionMenu_escape,
                              OptionSize, Blue, Back, true),
       escape_button_(new ButtonComponent),
-      typing_property_(common_->font, OptionMenu_typing,
+      typing_property_(common_->font_, OptionMenu_typing,
                        NormalSize, Fore, Back, true),
       typing_surface_(new TextSurface(typing_property_)),
       typing_label_(new LabelComponent(typing_surface_)),
-      sound_property_(common_->font, OptionMenu_sound,
+      sound_property_(common_->font_, OptionMenu_sound,
                       NormalSize, Fore, Back, true),
       sound_surface_(new TextSurface(sound_property_)),
       sound_label_(new LabelComponent(sound_surface_)),
-      system_property_(common_->font, OptionMenu_system,
+      system_property_(common_->font_, OptionMenu_system,
                       NormalSize, Fore, Back, true),
       system_surface_(new TextSurface(system_property_)),
       system_label_(new LabelComponent(system_surface_)),
@@ -158,7 +168,7 @@ struct OptionMenu::pImpl {
     typing_label_->setPosition(&position);
 
     // - K
-    TextProperty practice_num(common_->font, OptionMenu_typing_num,
+    TextProperty practice_num(common_->font_, OptionMenu_typing_num,
                               OptionSize, Fore, Back, true);
     practice_num_selector_->addItem(PracticeNum_5);
     practice_num_selector_->addItem(PracticeNum_10);
@@ -171,7 +181,7 @@ struct OptionMenu::pImpl {
     option_->addItem(practice_num, practice_num_selector_, PlaceOffset, Middle);
 
     // - ̓[h
-    TextProperty practice_input(common_->font, OptionMenu_input,
+    TextProperty practice_input(common_->font_, OptionMenu_input,
                                 OptionSize, Fore, Back, true);
     practice_input_selector_->addItem(OptionMenu_Roman);
     practice_input_selector_->addItem(OptionMenu_Kana);
@@ -182,13 +192,15 @@ struct OptionMenu::pImpl {
                      practice_input_selector_, PlaceOffset, Middle);
 
     // - 񓯂o肷
-    TextProperty practice_mode(common_->font, OptionMenu_eachtime_title,
+    TextProperty practice_mode(common_->font_, OptionMenu_eachtime_title,
                                OptionSize, Fore, Back, true);
-    TextProperty practice_eachtime(common_->font, OptionMenu_eachtime,
+    TextProperty practice_eachtime(common_->font_, OptionMenu_eachtime,
                                    OptionSize, Fore, Back, true);
     Surface practice_eachtime_surface(new TextSurface(practice_eachtime));
     practice_eachtime_cbox_->setSurface(practice_eachtime_surface, 24, 0);
-    practice_eachtime_cbox_->setCheck(true);
+    practice_eachtime_cbox_->
+      setCheck((common_->getPracticeWakaNo() >= 0) ? true : false);
+    practice_eachtime_cbox_->isCheckChanged();
     option_->addItem(practice_mode,
                      practice_eachtime_cbox_, PlaceOffset, Middle);
 
@@ -199,32 +211,46 @@ struct OptionMenu::pImpl {
     option_->addItemOffset(0, OptionSize + (TextOffset * 3));
 
     // - wi
-    TextProperty sound_music(common_->font, OptionMenu_music,
+    TextProperty sound_music(common_->font_, OptionMenu_music,
                              OptionSize, Fore, Back, true);
-    int volume = common_->settings->music_volume_[user_index_];
+    int volume = common_->settings_->music_volume_[user_index_];
     sound_music_vslider_->setValue(volume);
     option_->addItem(sound_music, sound_music_vslider_, PlaceOffset, Middle);
 
     // - ʉ
-    TextProperty sound_effect(common_->font, OptionMenu_effect,
+    TextProperty sound_effect(common_->font_, OptionMenu_effect,
                              OptionSize, Fore, Back, true);
-    volume = common_->settings->effect_volume_[user_index_];
+    volume = common_->settings_->effect_volume_[user_index_];
     sound_effect_vslider_->setValue(volume);
     option_->addItem(sound_effect, sound_effect_vslider_, PlaceOffset, Middle);
 
     // - rݏグ
-    TextProperty sound_voice(common_->font, OptionMenu_voice,
+    TextProperty sound_voice(common_->font_, OptionMenu_voice,
                              OptionSize, Fore, Back, true);
-    TextProperty normal_property(common_->font, OptionMenu_cdrom,
-                                 OptionSize - 4, Fore, Back, true);
-    TextProperty selected_property(common_->font, OptionMenu_cdrom,
-                                   OptionSize - 4, Selected, Back, true);
-    boost::shared_ptr<ButtonComponent> cdrom_button(new ButtonComponent);
-    ButtonComponent::createButton(cdrom_button, normal_property,
-                                  selected_property, selected_property);
-    // !!! f[^\[X̍ڂǉ
+    sound_voice_combobox_->setFrameColor(White);
+    sound_voice_combobox_->setDecidedBackgroundColor(White);
+    sound_voice_combobox_->setSelectedBackgroundColor(Blue);
     sound_voice_combobox_->setRightOffset(TextOffset);
-    sound_voice_combobox_->addItem(cdrom_button);
+
+    std::vector<std::string> texts = voice_resources_;
+    TextProperty normal(common_->font_, "", OptionSize - 4,
+                        Fore, White, true);
+    TextProperty selected(common_->font_, "", OptionSize - 4,
+                          White, Blue, true);
+    ComboBoxComponent::createComboBox(sound_voice_combobox_,
+                                      texts, normal, selected, White);
+
+    // ICfbNX̌
+    std::string voice_resource_name = common_->getVoiceResource();
+    // !!! data_CD-ROM.txt w肷ƁA܂ɂȂ邪Aۗ
+    index = 0;
+    for (std::vector<std::string>::iterator it = texts.begin();
+         it != texts.end(); ++it, ++index) {
+      if (! it->compare(voice_resource_name)) {
+        sound_voice_combobox_->setSelected(index);
+        break;
+      }
+    }
     option_->addItem(sound_voice, sound_voice_combobox_, PlaceOffset, Middle);
 
     // VXe
@@ -236,9 +262,9 @@ struct OptionMenu::pImpl {
 #if 0
     // !!! Ƃ肠A
     // - ʃ[h
-    TextProperty system_full_title(common_->font, OptionMenu_full_title,
+    TextProperty system_full_title(common_->font_, OptionMenu_full_title,
                                OptionSize, Fore, Back, true);
-    TextProperty system_full(common_->font, OptionMenu_full,
+    TextProperty system_full(common_->font_, OptionMenu_full,
                                      OptionSize, Fore, Back, true);
     Surface system_full_surface(new TextSurface(system_full));
     system_full_cbox_->setSurface(system_full_surface, 24, 0);
@@ -247,13 +273,14 @@ struct OptionMenu::pImpl {
 #endif
 
     // - ^CsOf[^T[oɑM
-    TextProperty system_send_title(common_->font, OptionMenu_send_title,
+    TextProperty system_send_title(common_->font_, OptionMenu_send_title,
                                OptionSize, Fore, Back, true);
-    TextProperty system_send(common_->font, OptionMenu_send,
+    TextProperty system_send(common_->font_, OptionMenu_send,
                                      OptionSize, Fore, Back, true);
     Surface system_send_surface(new TextSurface(system_send));
     system_send_cbox_->setSurface(system_send_surface, 24, 0);
-    system_send_cbox_->setCheck(true);
+    system_send_cbox_->setCheck(common_->isSendData());
+    system_send_cbox_->isCheckChanged();
     option_->addItem(system_send_title, system_send_cbox_, PlaceOffset, Middle);
 
     // Đ{^̍쐬
@@ -284,28 +311,32 @@ struct OptionMenu::pImpl {
     set_SdlRect(&position, rightPosition(escape_button_, 640) - TextOffset,
                 bottomPosition(escape_button_, 480) - TextOffset);
     escape_button_->setPosition(&position);
+
+    // xɑΏ
+    //if (OptionMenu_full_title || OptionMenu_full);
+    //if (PracticeNum_left || PracticeNum_syu || PracticeNum_complete);
   }
 
   void placeComponents(void) {
-    common_->front_layer->push_front(title_label_);
-    common_->front_layer->push_front(sound_label_);
-    common_->front_layer->push_front(system_label_);
-    common_->front_layer->push_front(escape_button_);
-    common_->front_layer->push_front(typing_label_);
-    common_->front_layer->push_front(option_);
-    common_->front_layer->push_front(speaker_button_);
-    common_->front_layer->push_front(common_->user_label);
+    common_->front_layer_->push_front(title_label_);
+    common_->front_layer_->push_front(sound_label_);
+    common_->front_layer_->push_front(system_label_);
+    common_->front_layer_->push_front(escape_button_);
+    common_->front_layer_->push_front(typing_label_);
+    common_->front_layer_->push_front(option_);
+    common_->front_layer_->push_front(speaker_button_);
+    common_->front_layer_->push_front(common_->user_label_);
   }
 
   void removeComponents(void) {
-    common_->front_layer->remove(title_label_);
-    common_->front_layer->remove(sound_label_);
-    common_->front_layer->remove(system_label_);
-    common_->front_layer->remove(escape_button_);
-    common_->front_layer->remove(typing_label_);
-    common_->front_layer->remove(option_);
-    common_->front_layer->remove(speaker_button_);
-    common_->front_layer->remove(common_->user_label);
+    common_->front_layer_->remove(title_label_);
+    common_->front_layer_->remove(sound_label_);
+    common_->front_layer_->remove(system_label_);
+    common_->front_layer_->remove(escape_button_);
+    common_->front_layer_->remove(typing_label_);
+    common_->front_layer_->remove(option_);
+    common_->front_layer_->remove(speaker_button_);
+    common_->front_layer_->remove(common_->user_label_);
   }
 
   // ύX̔f
@@ -315,40 +346,57 @@ struct OptionMenu::pImpl {
     int decided = practice_num_selector_->getDecided();
     if (decided >= 0) {
       int num_array[] = { 5, 10, 50, 100 };
-      common_->settings->practice_num_[user_index_] = num_array[decided];
+      common_->settings_->practice_num_[user_index_] = num_array[decided];
       practice_num_selector_->releaseDecided();
     }
 
     // ̓[h̕ύX
     decided = practice_input_selector_->getDecided();
     if (decided >= 0) {
-      common_->settings->convert_mode_[user_index_] = decided;
+      common_->settings_->convert_mode_[user_index_] = decided;
       practice_input_selector_->releaseDecided();
     }
 
     // {[̕ύX
     if (sound_music_vslider_->isChanged()) {
       int volume = sound_music_vslider_->getValue();
-      common_->settings->music_volume_[user_index_] = volume;
+      common_->settings_->music_volume_[user_index_] = volume;
       common_->updateSoundVolume(volume);
     }
     if (sound_effect_vslider_->isChanged()) {
       int volume = sound_effect_vslider_->getValue();
-      common_->settings->effect_volume_[user_index_] = volume;
+      common_->settings_->effect_volume_[user_index_] = volume;
       common_->updateEffectVolume(volume);
     }
 
     // Ao肷
-    // !!!
+    if (practice_eachtime_cbox_->isCheckChanged()) {
 
-    // ʃ[hݒ
-    // !!!
+      // O܂ł̘a̔ԍۑ
+      int current = common_->settings_->practice_mode_[user_index_];
+      int next = -current - 1;
+      common_->settings_->practice_mode_[user_index_] = next;
+    }
+
+    // f[^𑗐M
+    if (system_send_cbox_->isCheckChanged()) {
+      common_->settings_->data_send_[user_index_] =
+        (system_send_cbox_->isChecked()) ? 0 : 1;
+    }
 
     // ʉ炷
     if (speaker_button_->isDecided()) {
       common_->playEffect(Decide);
       speaker_button_->releaseDecided();
     }
+
+    // rݏグ\[X
+    if (sound_voice_combobox_->isSelectChanged()) {
+      int selected = sound_voice_combobox_->getSelected();
+      // CD-ROM w "" Ƃ
+      common_->settings_->voice_resource_[user_index_] =
+        (selected == 0) ? "" : voice_resources_[selected];
+    }
   }
 };
 
@@ -360,14 +408,14 @@ OptionMenu::OptionMenu(void) : pimpl(new pImpl) {
 
 OptionMenu::~OptionMenu(void) {
   pimpl->removeComponents();
-  pimpl->common_->settings->save();
+  pimpl->common_->settings_->save();
 }
 
 
 void OptionMenu::run(void) {
 
-  GuiManager* gui = pimpl->common_->gui;
-  InputHandler& input = *pimpl->common_->input;
+  GuiManager* gui = pimpl->common_->gui_;
+  InputHandler& input = *pimpl->common_->input_;
   bool quit = false;
   while (quit == false) {
 
