@@ -43,6 +43,7 @@ struct OptionMenuComponent::pImpl {
   std::vector<Grid<int> > component_offset_;
   std::vector<Grid<int> > items_offset_;
   std::vector<Component> components_;
+  std::vector<Grid<int> > components_position_;
 
   pImpl(void) : width_(0), height_(0), position_changed_(false),
                 icon_placed_(false), icon_place_mode_(None),
@@ -62,6 +63,7 @@ struct OptionMenuComponent::pImpl {
     component_offset_.clear();
     items_offset_.clear();
     components_.clear();
+    components_position_.clear();
   }
 
   void updateComponentSize(void) {
@@ -118,14 +120,7 @@ struct OptionMenuComponent::pImpl {
       }
 
       // R|[lg̔zu
-      Component& p = components_[index];
-      SDL_Rect component_rect;
-      set_SdlRect(&component_rect,
-                  position_.x + component_offset_[index].x + x,
-                  position_.y + component_offset_[index].y + y,
-                  p->getWidth(), p->getHeight());
-      p->setPosition(&component_rect);
-      p->addSurfaceList(surfaces, area, ticks);
+      components_[index]->addSurfaceList(surfaces, area, ticks);
 
       x += items_offset_[index].x;
       y += items_offset_[index].y;
@@ -185,18 +180,53 @@ struct OptionMenuComponent::pImpl {
     for (std::vector<Surface>::iterator it = titles_.begin();
          it != titles_.end(); ++it, ++index) {
 
+      // !!! Cɂ͂nĂ݂
+      // !!! A͂ꂽAȍ~ɂ͏nȂ悤ɂ
+      // !!! applied_rects 𔻒Ɏg
+
+      // !!! ƁAL[͂nȂHvKv
+      // !!!
+      InputEvent mouseOnly_event = event;
+      mouseOnly_event.key_pressed.clear();
+      mouseOnly_event.key_released.clear();
+
+      components_[index]->applyInput(mouseOnly_event, applied_rects);
+
       int y_top = position_.y + y;
       int y_bottom = y_top + (*it)->getHeight();
       if ((event.my >= y_top) && (event.my <= y_bottom)) {
         // }EX Y ʒuR|[lgɓ͂n
-        components_[index]->applyInput(event, applied_rects);
+        //components_[index]->applyInput(event, applied_rects);
         menu_index_ = index;
 
-        break;
+        //break;
       }
       y += items_offset_[index].y;
     }
   }
+
+  void setComponentsPosition(void) {
+
+    // ڂ̔zu
+    size_t x = 0;
+    size_t y = 0;
+    size_t index = 0;
+    for (std::vector<Surface>::iterator it = titles_.begin();
+         it != titles_.end(); ++it, ++index) {
+
+      // R|[lg̔zu
+      Component& p = components_[index];
+      SDL_Rect component_rect;
+      set_SdlRect(&component_rect,
+                  position_.x + component_offset_[index].x + x,
+                  position_.y + component_offset_[index].y + y,
+                  p->getWidth(), p->getHeight());
+      p->setPosition(&component_rect);
+
+      x += items_offset_[index].x;
+      y += items_offset_[index].y;
+    }
+  }
 };
 
 
@@ -219,6 +249,8 @@ void OptionMenuComponent::setPosition(const SDL_Rect* position) {
 
   set_SdlRect(&pimpl->position_, position->x, position->y,
               pimpl->width_, pimpl->height_);
+  pimpl->setComponentsPosition();
+
   pimpl->position_changed_ = true;
 }
 
