@@ -13,6 +13,8 @@
 #include "DetectOS.h"
 #ifndef MSC
 #include <unistd.h>
+#else
+#include <windows.h>
 #endif
 
 void beego::removeFile(const char *file) {
@@ -20,6 +22,6 @@ void beego::removeFile(const char *file) {
 #ifndef WINDOWS_OS
   unlink(file);
 #else
-  // !!!
+  DeleteFileA(file);
 #endif
 }
