@@ -5,8 +5,6 @@
   \author Satofumi KAMIMURA
 
   $Id$
-
-  \todo uIvACRƋɍ폜bZ[W\AƂH
 */
 
 #include "RemoveUser.h"
@@ -16,6 +14,7 @@
 #include "DrawsDefinition.h"
 #include "AccessSettings.h"
 #include "arrow_bmp.h"
+#include "warn_bmp.h"
 #include "GuiManager.h"
 #include "Layer.h"
 #include "InputHandler.h"
@@ -44,46 +43,46 @@ struct RemoveUser::pImpl {
   enum { MessageY = 285 };
 
   class Schedule : public BaseEntity {
-    StateMachine<Schedule>* state_machine;
-    bool is_terminated;
+    StateMachine<Schedule>* state_machine_;
+    bool is_terminated_;
 
   public:
-    Schedule(int id, CommonResources* common)
-      : BaseEntity(id), is_terminated(false) {
-      state_machine = new StateMachine<Schedule>(this);
-      state_machine->setCurrentState(FirstState::getObject(common));
+    Schedule(int id, CommonResources* common_)
+      : BaseEntity(id), is_terminated_(false) {
+      state_machine_ = new StateMachine<Schedule>(this);
+      state_machine_->setCurrentState(FirstState::getObject(common_));
     }
 
     ~Schedule(void) {
-      delete state_machine;
+      delete state_machine_;
     }
 
     void update(void) {
-      state_machine->update();
+      state_machine_->update();
     }
 
     void changeState(State<Schedule>* new_state) {
-      state_machine->changeState(new_state);
+      state_machine_->changeState(new_state);
     }
 
     void setTerminate(void) {
-      is_terminated = true;
+      is_terminated_ = true;
     }
 
     bool isTerminated(void) {
-      return is_terminated;
+      return is_terminated_;
     }
   };
 
   class FirstState : public State<Schedule> {
-    CommonResources* common;
+    CommonResources* common_;
 
-    FirstState(CommonResources* common_obj) : common(common_obj) {
+    FirstState(CommonResources* common_) : common_(common_) {
     }
 
   public:
-    static FirstState* getObject(CommonResources* common) {
-      static FirstState obj(common);
+    static FirstState* getObject(CommonResources* common_) {
+      static FirstState obj(common_);
       return &obj;
     }
 
@@ -92,7 +91,7 @@ struct RemoveUser::pImpl {
     }
 
     void execute(Schedule* type) {
-      type->changeState(SelectUserState::getObject(common));
+      type->changeState(SelectUserState::getObject(common_));
     }
 
     void exit(Schedule* type) {
@@ -103,7 +102,7 @@ struct RemoveUser::pImpl {
     enum {
       RectWidth = MenuSize * 18/2,
     };
-    CommonResources* common;
+    CommonResources* common_;
     boost::shared_ptr<MenuComponent> menu_;
     Surface back_surface_;
     Component back_label_;
@@ -112,8 +111,8 @@ struct RemoveUser::pImpl {
     boost::shared_ptr<SwitchSurface> message_;
     Component message_label_;
 
-    SelectUserState(CommonResources* common_obj)
-      : common(common_obj), menu_(new MenuComponent),
+    SelectUserState(CommonResources* common_)
+      : common_(common_), menu_(new MenuComponent),
         back_surface_(new ColorSurface(RectWidth,
                                        MenuSize * (UserMax + 1), Black)),
         back_label_(new LabelComponent(back_surface_)),
@@ -124,8 +123,8 @@ struct RemoveUser::pImpl {
     }
 
   public:
-    static SelectUserState* getObject(CommonResources* common) {
-      static SelectUserState obj(common);
+    static SelectUserState* getObject(CommonResources* common_) {
+      static SelectUserState obj(common_);
       return &obj;
     }
 
@@ -136,8 +135,8 @@ struct RemoveUser::pImpl {
       size_t max_width = 0;
       menu_->clearItems();
       for (std::vector<std::string>::iterator it =
-             common->settings->user_names_.begin();
-           it != common->settings->user_names_.end(); ++it) {
+             common_->settings_->user_names_.begin();
+           it != common_->settings_->user_names_.end(); ++it) {
 
         const char* user_name = it->c_str();
         if (strlen(user_name) <= 0) {
@@ -147,9 +146,9 @@ struct RemoveUser::pImpl {
 
         // [Uڂ̒ǉ
         boost::shared_ptr<ButtonComponent> new_button(new ButtonComponent);
-        TextProperty normal(common->font, user_name, MenuSize,
+        TextProperty normal(common_->font_, user_name, MenuSize,
                             White, Gray3, true);
-        TextProperty selected(common->font, user_name, MenuSize,
+        TextProperty selected(common_->font_, user_name, MenuSize,
                               White, Gray3, true);
         ButtonComponent::createButton(new_button, normal, selected, selected);
         if (new_button->getWidth() > max_width) {
@@ -167,8 +166,8 @@ struct RemoveUser::pImpl {
       std::swap(message_, new_message);
       int index = 0;
       for (std::vector<std::string>::iterator it =
-             common->settings->user_names_.begin();
-           it != common->settings->user_names_.end(); ++it, ++index) {
+             common_->settings_->user_names_.begin();
+           it != common_->settings_->user_names_.end(); ++it, ++index) {
 
         const char* user_name = it->c_str();
         if (strlen(user_name) <= 0) {
@@ -177,7 +176,7 @@ struct RemoveUser::pImpl {
 
         if (index == 0) {
           // uftHg[U͍폜ł܂v
-          TextProperty no_remove(common->font, RemoveUser_no_remove,
+          TextProperty no_remove(common_->font_, RemoveUser_no_remove,
                                  NormalSize, Fore, Back, true);
           Surface no_remove_surface(new TextSurface(no_remove));
           message_->registerSurface(no_remove_surface, 0, 0, index);
@@ -187,7 +186,7 @@ struct RemoveUser::pImpl {
           std::vector<Uint16> text;
           ustrcat(text, user_name);
           ustrcat(text, RemoveUser_remove);
-          TextProperty text_property(common->font, &text[0],
+          TextProperty text_property(common_->font_, &text[0],
                                      NormalSize, Fore, Back, true);
           Surface surface(new TextSurface(text_property));
           message_->registerSurface(surface, 0, 0, index);
@@ -232,7 +231,7 @@ struct RemoveUser::pImpl {
         menu_->releaseDecided();
       } else if (decided > 0) {
         // 폜mF
-        type->changeState(YesNoState::getObject(common));
+        type->changeState(YesNoState::getObject(common_));
       }
     }
 
@@ -241,16 +240,16 @@ struct RemoveUser::pImpl {
 
     void placeComponents(void) {
 
-      common->front_layer->push_front(back_label_);
-      common->front_layer->push_front(menu_);
-      common->front_layer->push_front(message_label_);
+      common_->front_layer_->push_front(back_label_);
+      common_->front_layer_->push_front(menu_);
+      common_->front_layer_->push_front(message_label_);
     }
 
     void removeComponents(void) {
 
-      common->front_layer->remove(back_label_);
-      common->front_layer->remove(menu_);
-      common->front_layer->remove(message_label_);
+      common_->front_layer_->remove(back_label_);
+      common_->front_layer_->remove(menu_);
+      common_->front_layer_->remove(message_label_);
     }
 
     int getRemoveUserIndex(void) {
@@ -259,32 +258,38 @@ struct RemoveUser::pImpl {
   };
 
   class YesNoState : public State<Schedule> {
-    CommonResources* common;
-    TextProperty yes_no_property;
-    Surface yes_no_surface;
-    Component yes_no_label;
-    TextProperty selector_property;
-    boost::shared_ptr<SelectComponent> selector;
+    CommonResources* common_;
+    TextProperty yes_no_property_;
+    Surface yes_no_surface_;
+    Component yes_no_label_;
+    Surface warn_surface_;
+    Component warn_label_;
+    TextProperty selector_property_;
+    boost::shared_ptr<SelectComponent> selector_;
 
-    YesNoState(CommonResources* common_obj)
-      : common(common_obj),
-        yes_no_property(common->font, RemoveUser_yes_no,
-                        NormalSize, Fore, Back, true),
-        yes_no_surface(new TextSurface(yes_no_property)),
-        yes_no_label(new LabelComponent(yes_no_surface)),
-        selector_property(common->font, "", NormalSize, Fore, Back, true),
-        selector(new SelectComponent(selector_property, White,
-                                     SelectComponent::UnderBar)) {
+    YesNoState(CommonResources* common_)
+      : common_(common_),
+        yes_no_property_(common_->font_, RemoveUser_yes_no,
+                         NormalSize, Fore, Back, true),
+        yes_no_surface_(new TextSurface(yes_no_property_)),
+        yes_no_label_(new LabelComponent(yes_no_surface_)),
+        warn_surface_(new SdlSurface(createSurface(warn_bmp,
+                                                   warn_bmp_width,
+                                                   warn_bmp_height), true)),
+        warn_label_(new LabelComponent(warn_surface_)),
+        selector_property_(common_->font_, "", NormalSize, Fore, Back, true),
+        selector_(new SelectComponent(selector_property_, White,
+                                      SelectComponent::UnderBar)) {
 
-      selector->addItem("Yes");
-      selector->addItem("No");
-      selector->setItemsOffset(16);
-      selector->enableInput();
+      selector_->addItem("Yes");
+      selector_->addItem("No");
+      selector_->setItemsOffset(16);
+      selector_->enableInput();
     }
 
   public:
-    static YesNoState* getObject(CommonResources* common) {
-      static YesNoState obj(common);
+    static YesNoState* getObject(CommonResources* common_) {
+      static YesNoState obj(common_);
       return &obj;
     }
 
@@ -292,31 +297,37 @@ struct RemoveUser::pImpl {
 
       // u{ɂ낵łHv̔zu
       SDL_Rect position;
-      set_SdlRect(&position, centerPosition(yes_no_label, 640/2),
+      set_SdlRect(&position, centerPosition(yes_no_label_, 640/2) + 10
+                  + (32 + TextOffset)/2,
                   MessageY + NormalSize + TextOffset);
-      yes_no_label->setPosition(&position);
+      yes_no_label_->setPosition(&position);
+
+      // xACR̔zu
+      position.x -= 32 + TextOffset - 2;
+      position.y -= (32 - NormalSize)/2 + 2;
+      warn_label_->setPosition(&position);
 
       // uYes / Nov̔zu
-      set_SdlRect(&position, centerPosition(selector, 640/2),
+      set_SdlRect(&position, centerPosition(selector_, 640/2),
                   position.y + NormalSize + TextOffset);
-      selector->setPosition(&position);
-      selector->releaseDecided();
-      selector->setSelected(1);
+      selector_->setPosition(&position);
+      selector_->releaseDecided();
+      selector_->setSelected(1);
 
       placeComponents();
     }
 
     void execute(Schedule* type) {
 
-      int decided = selector->getDecided();
+      int decided = selector_->getDecided();
       if (decided >= 0) {
         if (decided == 0) {
           // Yes
           int remove_index =
-            SelectUserState::getObject(common)->getRemoveUserIndex();
-          common->deleteUser(remove_index);
+            SelectUserState::getObject(common_)->getRemoveUserIndex();
+          common_->deleteUser(remove_index);
         }
-        type->changeState(SelectUserState::getObject(common));
+        type->changeState(SelectUserState::getObject(common_));
       }
     }
 
@@ -325,47 +336,49 @@ struct RemoveUser::pImpl {
     }
 
     void placeComponents(void) {
-      common->front_layer->push_front(yes_no_label);
-      common->front_layer->push_front(selector);
+      common_->front_layer_->push_front(yes_no_label_);
+      common_->front_layer_->push_front(warn_label_);
+      common_->front_layer_->push_front(selector_);
     }
 
     void removeComponents(void) {
-      SelectUserState::getObject(common)->removeComponents();
-      common->front_layer->remove(yes_no_label);
-      common->front_layer->remove(selector);
+      SelectUserState::getObject(common_)->removeComponents();
+      common_->front_layer_->remove(yes_no_label_);
+      common_->front_layer_->remove(warn_label_);
+      common_->front_layer_->remove(selector_);
     }
   };
 
-  CommonResources* common;
-  Schedule scheduler;
-  TextProperty title_property;
-  Surface title_surface;
-  Component title_label;
-  TextProperty back_property;
+  CommonResources* common_;
+  Schedule scheduler_;
+  TextProperty title_property_;
+  Surface title_surface_;
+  Component title_label_;
+  TextProperty back_property_;
   TextProperty back_focus_property_;
   boost::shared_ptr<ButtonComponent> back_button_;
 
   pImpl(void)
-    : common(CommonResources::getObject()),
-      scheduler(0, common),
-      title_property(common->font, RemoveUser_title,
-                     MenuSize, Fore, Back, true),
-      title_surface(new TextSurface(title_property)),
-      title_label(new LabelComponent(title_surface)),
-      back_property(common->font, RemoveUser_back_message,
-                    NormalSize, Fore, Back, true),
-      back_focus_property_(common->font, RemoveUser_back_message,
+    : common_(CommonResources::getObject()),
+      scheduler_(0, common_),
+      title_property_(common_->font_, RemoveUser_title,
+                      MenuSize, Fore, Back, true),
+      title_surface_(new TextSurface(title_property_)),
+      title_label_(new LabelComponent(title_surface_)),
+      back_property_(common_->font_, RemoveUser_back_message,
+                     NormalSize, Fore, Back, true),
+      back_focus_property_(common_->font_, RemoveUser_back_message,
                            NormalSize, Blue, Back, true),
       back_button_(new ButtonComponent()) {
 
-    ButtonComponent::createButton(back_button_, back_property,
+    ButtonComponent::createButton(back_button_, back_property_,
                                   back_focus_property_, back_focus_property_);
 
     // ^Cgʒu
     SDL_Rect position;
-    set_SdlRect(&position, centerPosition(title_label, 640/2),
-                topPosition(title_label, 0) + TextOffset * 3);
-    title_label->setPosition(&position);
+    set_SdlRect(&position, centerPosition(title_label_, 640/2),
+                topPosition(title_label_, 0) + TextOffset * 3);
+    title_label_->setPosition(&position);
 
     // ߂邽߂̃bZ[Wʒu
     set_SdlRect(&position, rightPosition(back_button_, 640) - TextOffset,
@@ -374,14 +387,14 @@ struct RemoveUser::pImpl {
   }
 
   void placeComponents(void) {
-    common->front_layer->push_front(title_label);
-    common->front_layer->push_front(back_button_);
+    common_->front_layer_->push_front(title_label_);
+    common_->front_layer_->push_front(back_button_);
   }
 
   void removeComponents(void) {
-    YesNoState::getObject(common)->removeComponents();
-    common->front_layer->remove(title_label);
-    common->front_layer->remove(back_button_);
+    YesNoState::getObject(common_)->removeComponents();
+    common_->front_layer_->remove(title_label_);
+    common_->front_layer_->remove(back_button_);
   }
 };
 
@@ -398,21 +411,22 @@ RemoveUser::~RemoveUser(void) {
 
 void RemoveUser::run(void) {
 
-  GuiManager* gui = pimpl->common->gui;
-  InputHandler& input = *pimpl->common->input;
+  GuiManager* gui = pimpl->common_->gui_;
+  InputHandler& input = *pimpl->common_->input_;
   bool quit = false;
   bool escape_pressed = false;
   while (quit == false) {
 
     // Ԃ̍XV
-    pimpl->scheduler.update();
+    pimpl->scheduler_.update();
 
     // I
-    quit |= pimpl->scheduler.isTerminated() || pimpl->back_button_->isDecided();
+    quit |= pimpl->scheduler_.isTerminated() ||
+      pimpl->back_button_->isDecided();
     gui->update();
     input.update_all();
     if (input.haveQuitEvent()) {
-      pimpl->common->front_layer->disable();
+      pimpl->common_->front_layer_->disable();
       quit |= true;
     }
     escape_pressed |= input.isPressed(SDLK_ESCAPE);
