@@ -10,11 +10,7 @@
 #include "SdlAudioInit.h"
 #include "SdlInit.h"
 #include "LogManager.h"
-#ifdef MSC
-#include "SDL_win.h"
-#else
 #include <SDL.h>
-#endif
 #include <stdlib.h>
 #include <string>
 
@@ -33,7 +29,8 @@ SdlAudioInit::SdlAudioInit(void) : pimpl(new pImpl) {
     if (SDL_InitSubSystem(SDL_INIT_AUDIO) < 0) {
       // OL^
       LogManager* log = LogManager::getObject();
-      std::string message = "SDL_Init(): " + std::string(SDL_GetError());
+      std::string message = "SDL_InitSubSystem(SDL_INIT_AUDIO): " +
+        std::string(SDL_GetError());
       log->write(LogManager::Error, message.c_str());
     }
     atexit(SDL_Quit);
