@@ -85,8 +85,6 @@ void SdlSurface::draw(std::vector<SDL_Rect>& update_rects,
     return;
   }
 
-  //fprintf(stderr, "SdlSurface::draw: %d, %d, %d, %d\n", pos->x, pos->y, pos->w, pos->h);
-
   SDL_BlitSurface(pimpl->surface, const_cast<SDL_Rect*>(area),
                   pimpl->scr, const_cast<SDL_Rect*>(pos));
   update_rects.push_back(*pos);
@@ -132,3 +130,8 @@ void SdlSurface::setAlpha(size_t percent) {
     pimpl->is_transparent = (percent >= 100) ? false : true;
   }
 }
+
+
+SDL_Surface* SdlSurface::getRawSurface(void) {
+  return pimpl->surface;
+}
