@@ -13,6 +13,7 @@
 #include "SdlVideoInit.h"
 #include "LockGuard.h"
 #include "LogManager.h"
+#include "SdlSurface.h"
 #include <string>
 
 using namespace beego;
@@ -26,32 +27,36 @@ using namespace SDL;
   \todo Windows ɂ show(), hide() JԂہAshow() ̕Ԃl]
 */
 struct SdlVideo::pImpl : private SdlVideoInit {
-  std::string error_message;
-  SDL_mutex* mutex;
-  bool initialized;
-  std::string caption;
+  std::string error_message_;
+  SDL_mutex* mutex_;
+  bool initialized_;
+  std::string caption_;
 
   enum {
     DefaultWidth = 640,
     DefaultHeight = 480,
     DefaultBpp = 0,             //!< ftHg[x𗘗p
   };
-  size_t now_w;
-  size_t now_h;
-  size_t next_bpp;
-  size_t next_w;
-  size_t next_h;
-  bool fullscreen;
+  size_t now_w_;
+  size_t now_h_;
+  size_t next_bpp_;
+  size_t next_w_;
+  size_t next_h_;
+  bool fullscreen_;
+
+  SDL_Surface* icon_surface_;
+  Uint8* icon_mask_;
 
   pImpl(void)
-    : error_message("no error."),
-      mutex(SDL_CreateMutex()), initialized(false), caption(""),
-      now_w(0), now_h(0), next_bpp(DefaultBpp),
-      next_w(DefaultWidth), next_h(DefaultHeight), fullscreen(false) {
+    : error_message_("no error."),
+      mutex_(SDL_CreateMutex()), initialized_(false), caption_(""),
+      now_w_(0), now_h_(0), next_bpp_(DefaultBpp),
+      next_w_(DefaultWidth), next_h_(DefaultHeight), fullscreen_(false),
+      icon_surface_(NULL), icon_mask_(NULL) {
   }
 
   ~pImpl(void) {
-    SDL_DestroyMutex(mutex);
+    SDL_DestroyMutex(mutex_);
   }
 
   static pImpl* getObject(void) {
@@ -71,19 +76,19 @@ SdlVideo::~SdlVideo(void) {
 
 
 const char* SdlVideo::what(void) {
-  return pimpl->error_message.c_str();
+  return pimpl->error_message_.c_str();
 }
 
 
 void SdlVideo::setFullscreenMode(bool on) {
-  pimpl->fullscreen = on;
+  pimpl->fullscreen_ = on;
 }
 
 
 SDL_Surface* SdlVideo::show(Uint32 mode) {
-  LockGuard guard(pimpl->mutex);
+  LockGuard guard(pimpl->mutex_);
 
-  if (pimpl->initialized) {
+  if (pimpl->initialized_) {
     return SDL_GetVideoSurface();
   }
 
@@ -95,25 +100,30 @@ SDL_Surface* SdlVideo::show(Uint32 mode) {
     return NULL;
   }
 
+  // ACR̓Kp
+  if (pimpl->icon_surface_) {
+    SDL_WM_SetIcon(pimpl->icon_surface_, pimpl->icon_mask_);
+  }
+
   // T[tFXɊւLqȂ΁ASDL_SWSURFACE [hœ삳
   mode = (mode == 0) ? SDL_SWSURFACE : mode;
-  mode |= pimpl->fullscreen ? SDL_FULLSCREEN : 0;
+  mode |= pimpl->fullscreen_ ? SDL_FULLSCREEN : 0;
 
   // !!! Windows ŁASDL_Flip() ̕]s
 
   SDL_Surface* scr =
-    SDL_SetVideoMode(static_cast<int>(pimpl->next_w),
-                     static_cast<int>(pimpl->next_h),
-                     static_cast<int>(pimpl->next_bpp), mode);
+    SDL_SetVideoMode(static_cast<int>(pimpl->next_w_),
+                     static_cast<int>(pimpl->next_h_),
+                     static_cast<int>(pimpl->next_bpp_), mode);
   if (scr == NULL) {
-    pimpl->error_message = SDL_GetError();
+    pimpl->error_message_ = SDL_GetError();
   }
-  pimpl->initialized = (scr == NULL) ? false : true;
+  pimpl->initialized_ = (scr == NULL) ? false : true;
 
-  if (pimpl->initialized != false) {
-    pimpl->now_w = pimpl->next_w;
-    pimpl->now_h = pimpl->next_h;
-    SDL_WM_SetCaption(pimpl->caption.c_str(), NULL);
+  if (pimpl->initialized_ != false) {
+    pimpl->now_w_ = pimpl->next_w_;
+    pimpl->now_h_ = pimpl->next_h_;
+    SDL_WM_SetCaption(pimpl->caption_.c_str(), NULL);
   }
 
   return scr;
@@ -121,38 +131,44 @@ SDL_Surface* SdlVideo::show(Uint32 mode) {
 
 
 void SdlVideo::hide(void) {
-  if (pimpl->initialized) {
-    LockGuard guard(pimpl->mutex);
+  if (pimpl->initialized_) {
+    LockGuard guard(pimpl->mutex_);
 
     SDL_QuitSubSystem(SDL_INIT_VIDEO);
-    pimpl->initialized = false;
-    pimpl->now_w = 0;
-    pimpl->now_h = 0;
+    pimpl->initialized_ = false;
+    pimpl->now_w_ = 0;
+    pimpl->now_h_ = 0;
   }
 }
 
 
 void SdlVideo::setCaption(const char* caption) {
-  pimpl->caption = caption;
+  pimpl->caption_ = caption;
+}
+
+
+void SdlVideo::setIcon(SDL_Surface* icon_surface, Uint8* mask) {
+  pimpl->icon_surface_ = icon_surface;
+  pimpl->icon_mask_ = mask;
 }
 
 
 void SdlVideo::setWindowBpp(size_t bpp) {
-  pimpl->next_bpp = bpp;
+  pimpl->next_bpp_ = bpp;
 }
 
 
 void SdlVideo::setWindowSize(size_t width, size_t height) {
-  pimpl->next_w = width;
-  pimpl->next_h = height;
+  pimpl->next_w_ = width;
+  pimpl->next_h_ = height;
 }
 
 
 size_t SdlVideo::getWidth(void) {
-  return pimpl->now_w;
+  return pimpl->now_w_;
 }
 
 
 size_t SdlVideo::getHeight(void) {
-  return pimpl->now_h;
+  return pimpl->now_h_;
 }
