@@ -15,6 +15,7 @@
 
 
 namespace beego {
+  class SdlSurface;
 
   namespace SDL {
     /*!
@@ -37,6 +38,7 @@ namespace beego {
       void hide(void);
 
       void setCaption(const char* caption);
+      void setIcon(SDL_Surface* icon, Uint8* mask = NULL);
       void setWindowBpp(size_t bpp);
       void setWindowSize(size_t width, size_t height);
       size_t getWidth(void);
