@@ -23,7 +23,8 @@ struct SocketSet::pImpl {
 
 #if !HAVE_CONFIG_H || HAVE_LIBSDL_NET
   pImpl(size_t size)
-    : max_num(size), hold_num(0), socket_set(SDLNet_AllocSocketSet(max_num)) {
+    : max_num(size), hold_num(0),
+      socket_set(SDLNet_AllocSocketSet(static_cast<int>(max_num))) {
   }
 #else
   pImpl(size_t size) : max_num(size), hold_num(0), socket_set(NULL) {
