@@ -23,6 +23,7 @@ struct TypingTextConverter::pImpl {
   std::vector<Uint16> converted_text;
   TypingRecorder* recorder;
   size_t start_ticks;
+  ConvertType type_;
 
   pImpl(const Uint16* convertTable, size_t tableLength)
     : convert_table(convertTable), table_length(tableLength), recorder(NULL),
@@ -117,6 +118,7 @@ TypingTextConverter::TypingTextConverter(ConvertType type)
   : pimpl((type == Roman) ?
           new pImpl(RomanTable[0][0], ROMAN_CONVERT_SIZE_MAX) :
           new pImpl(KanaTable[0][0], KANA_CONVERT_SIZE_MAX)) {
+  pimpl->type_ = type;
 }
 
 
@@ -218,3 +220,8 @@ void TypingTextConverter::registerRecorder(TypingRecorder* recorder) {
 void TypingTextConverter::registerStartTicks(size_t start_ticks) {
   pimpl->start_ticks = start_ticks;
 }
+
+
+TypingTextConverter::ConvertType TypingTextConverter::getConvertType(void) {
+  return pimpl->type_;
+}
