@@ -8,6 +8,7 @@
 */
 
 #include "ViewHistory.h"
+#include "ResourceDefinition.h"
 #include "CommonResources.h"
 #include "GraphDrawer.h"
 #include "GuiManager.h"
@@ -25,34 +26,34 @@ using namespace beego;
 struct ViewHistory::pImpl {
 
   class Schedule : public BaseEntity {
-    bool is_terminated;
-    StateMachine<Schedule>* state_machine;
+    bool is_terminated_;
+    StateMachine<Schedule>* state_machine_;
 
   public:
     Schedule(int id, CommonResources* common)
-      : BaseEntity(id), is_terminated(false) {
-      state_machine = new StateMachine<Schedule>(this);
-      state_machine->setCurrentState(FirstState::getObject(common));
+      : BaseEntity(id), is_terminated_(false) {
+      state_machine_ = new StateMachine<Schedule>(this);
+      state_machine_->setCurrentState(FirstState::getObject(common));
     }
 
     ~Schedule(void) {
-      delete state_machine;
+      delete state_machine_;
     }
 
     void update(void) {
-      state_machine->update();
+      state_machine_->update();
     }
 
     void changeState(State<Schedule>* new_state) {
-      state_machine->changeState(new_state);
+      state_machine_->changeState(new_state);
     }
 
     void setTerminate(void) {
-      is_terminated = true;
+      is_terminated_ = true;
     }
 
     bool isTerminated(void) {
-      return is_terminated;
+      return is_terminated_;
     }
   };
 
@@ -74,7 +75,7 @@ struct ViewHistory::pImpl {
     }
 
     void execute(Schedule* type) {
-      common_->input_receiver->updateInputEvent(input_event_);
+      common_->input_receiver_->updateInputEvent(input_event_);
       if (InputEvent::isPressed(input_event_, SDLK_RETURN) ||
           input_event_.left_released) {
         type->changeState(ShimonokuViewState::getObject(common_));
@@ -108,7 +109,7 @@ struct ViewHistory::pImpl {
 
     void execute(Schedule* type) {
 
-      common_->input_receiver->updateInputEvent(input_event_);
+      common_->input_receiver_->updateInputEvent(input_event_);
       if (InputEvent::isReleased(input_event_, SDLK_RETURN) ||
           input_event_.left_released) {
         type->changeState(KimarijiViewState::getObject(common_));
@@ -122,13 +123,13 @@ struct ViewHistory::pImpl {
     void placeComponents(void) {
 
       graph_.placeComponents();
-      common_->input_receiver->clear();
+      common_->input_receiver_->clear();
     }
 
     void removeComponents(void) {
 
       graph_.removeComponents();
-      common_->input_receiver->clear();
+      common_->input_receiver_->clear();
     }
   };
 
@@ -149,13 +150,16 @@ struct ViewHistory::pImpl {
 
     void enter(Schedule* type) {
 
+      // ʉ炷
+      common_->playEffect(Decide);
+
       graph_.drawGraph();
       placeComponents();
     }
 
     void execute(Schedule* type) {
 
-      common_->input_receiver->updateInputEvent(input_event_);
+      common_->input_receiver_->updateInputEvent(input_event_);
       if (InputEvent::isReleased(input_event_, SDLK_RETURN) ||
           input_event_.left_released) {
         type->changeState(FirstState::getObject(common_));
@@ -169,31 +173,30 @@ struct ViewHistory::pImpl {
     void placeComponents(void) {
 
       graph_.placeComponents();
-      common_->input_receiver->clear();
+      common_->input_receiver_->clear();
     }
 
     void removeComponents(void) {
 
       graph_.removeComponents();
-      common_->input_receiver->clear();
+      common_->input_receiver_->clear();
     }
   };
 
-  CommonResources* common;
-  Schedule scheduler;
+  CommonResources* common_;
+  Schedule scheduler_;
 
   pImpl(void)
-    : common(CommonResources::getObject()),
-      scheduler(0, common) {
+    : common_(CommonResources::getObject()),
+      scheduler_(0, common_) {
   }
 
   void placeComponents(void) {
-    // !!!
   }
 
   void removeComponents(void) {
-    ShimonokuViewState::getObject(common)->removeComponents();
-    KimarijiViewState::getObject(common)->removeComponents();
+    ShimonokuViewState::getObject(common_)->removeComponents();
+    KimarijiViewState::getObject(common_)->removeComponents();
   }
 };
 
@@ -208,19 +211,19 @@ ViewHistory::~ViewHistory(void) {
 
 void ViewHistory::run(void) {
 
-  GuiManager* gui = pimpl->common->gui;
-  InputHandler& input = *pimpl->common->input;
+  GuiManager* gui = pimpl->common_->gui_;
+  InputHandler& input = *pimpl->common_->input_;
   bool quit = false;
   while (quit == false) {
 
     // Ԃ̍XV
-    pimpl->scheduler.update();
+    pimpl->scheduler_.update();
 
     // I
     input.update_all();
     gui->update();
 
-    quit |= pimpl->scheduler.isTerminated();
+    quit |= pimpl->scheduler_.isTerminated();
     quit |= input.haveQuitEvent() | input.isReleased(SDLK_ESCAPE);
     delay(1);
   }
