@@ -36,7 +36,9 @@ namespace beego {
     void registerLayer(Layer* layer);
 
     // !!! ̐ݒ
-    // !!! l̐ݒ
+    int getValue(void);
+    void setValue(int value);
+    bool isChanged(void);
     // !!! ʒuύX̋As
     // !!! F̕ω̂w
   };
